{% if params | default(none) is not none %}
aaa group server tacacs+ {{ params.name }}
{%   for server in params.servers %}
 server name {{ server.name }}
{%   endfor %}
{%   if params.vrf | default(none) is not none %}
 ip vrf forwarding {{ params.vrf }}
{%   endif %}
{%   if params.src_interface | default(none) is not none %}
 ip tacacs source-interface {{ params.src_interface }}
{%   endif %}
{% endif %}